@@ -9,6 +9,9 @@ DRBL_SCRIPT_PATH="${DRBL_SCRIPT_PATH:-/opt/drbl/}"
 . $DRBL_SCRIPT_PATH/conf/drbl-ocs.conf
 . $DRBL_SCRIPT_PATH/sbin/ocs-functions
 
+# Load the config in ocs-live.conf. This is specially for DRBL/Clonezilla live. It will overwrite some settings of /opt/drbl/conf/drbl-ocs.conf, such as $DIA...
+[ -e "/etc/ocs/ocs-live.conf" ] && . /etc/ocs/ocs-live.conf
+
 # functions
 USAGE() {
     echo "To start, restart or stop DRBL service in DRBL Live environment."
@@ -153,20 +156,24 @@ case "$switch" in
        fi
      fi
 
+     # ocs_client_no_per_NIC is read from /etc/ocs/ocs-live.conf, which might be from boot parameter.
+     if [ -n "$ocs_client_no_per_NIC" ]; then
+       LC_ALL=C perl -pi -e "s/^client_no_per_NIC=.*/client_no_per_NIC=$ocs_client_no_per_NIC/g" $drbl_setup_path/files/ocs/live-hook/ocs-live-hook.conf
+     fi
      # load $client_no_per_NIC and $autologin_passwd_opt for later use
      . $drbl_setup_path/files/ocs/live-hook/ocs-live-hook.conf
 
      # run drblpush again so that the network interface can be updated. Maybe there is new ethx.
-     yes "" | drblpush -i -r 1 -z 1 --not-add-start-drbl-srvi -p $client_no_per_NIC
+     yes "" | drblpush -i -r 1 -z 1 --not-add-start-drbl-srvi --skip-drbl-ocs-live-prep -p $client_no_per_NIC
 
      echo "$msg_delimiter_star_line"
-     if [ "$limit_pxeclient" = "yes" ]; then
+     if [ "$limit_pxe_drbl_client" = "yes" ]; then
        # modify dhcpd.conf, provide IP address to PXE/Etherboot/DRBL client only
        echo "Modifying dhcpd.conf, now only PXE/Etherboot/DRBL client can lease IP address from this server..."
-       perl -pi -e 's/^([[:space:]]*)#[[:space:]]*(allow members of "DRBL-Client";)/$1$2/g' /etc/dhcp3/dhcpd.conf
+       perl -pi -e 's/^([[:space:]]*)#[[:space:]]*(allow members of "DRBL-Client";)/$1$2/g' $DHCPDCONF_DIR/dhcpd.conf
      else
        echo "Modifying dhcpd.conf, now ANY client, not only PXE/Etherboot/DRBL client, can lease IP address from this server..."
-       perl -pi -e 's/^([[:space:]]*)#*[[:space:]]*(allow members of "DRBL-Client";)/$1#$2/g' /etc/dhcp3/dhcpd.conf
+       perl -pi -e 's/^([[:space:]]*)#*[[:space:]]*(allow members of "DRBL-Client";)/$1#$2/g' $DHCPDCONF_DIR/dhcpd.conf
      fi
 
      echo "$msg_delimiter_star_line"
